Added GSM network support.
[lcr.git] / options.c
index 160a8a8..b76059e 100644 (file)
--- a/options.c
+++ b/options.c
@@ -31,7 +31,8 @@ struct options options = {
        0,                              /* by default use priority 0 */
        "lcr@your.machine",             /* source mail adress */
        "/var/tmp",                     /* path of lock files */
-       0700                            /* rights of lcr admin socket */
+       0700,                           /* rights of lcr admin socket */
+       0                               /* enable gsm */
 };
 
 char options_error[256];
@@ -249,6 +250,10 @@ int read_options(void)
                {
                        options.socketrights = strtol(param, NULL, 0);
                } else
+               if (!strcmp(option,"gsm"))
+               {
+                       options.gsm = 1;
+               } else
                {
                        SPRINT(options_error, "Error in %s (line %d): wrong option keyword %s.\n", filename,line,option);
                        goto error;